@@ -1,10 +1,10 @@
-__version__ = "0.4.12"
+__version__ = "0.4.13"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
 __git_branch__ = '(Not currently on any branch)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '37f2e4b79fd9c7c362b0929eb289239521d2c766'
-__git_head_subject__ = 'Finished release v0.4.12.'
+__git_head_hash__ = 'fc45ba6025d7e82c9a5127dabafb2f10b773bb0f'
+__git_head_subject__ = 'fixing tests'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
